@@ -1,8 +1,9 @@
+from mockdata.mock_FHS import NoFHSPackage
 import pytest
 from rpmlint.checks.FHSCheck import FHSCheck
 from rpmlint.filter import Filter
 
-from Testing import CONFIG, get_tested_package
+from Testing import CONFIG
 
 
 @pytest.fixture(scope='function', autouse=True)
@@ -13,13 +14,13 @@ def fhscheck():
     return output, test
 
 
-@pytest.mark.parametrize('package', ['binary/non-fhs'])
-def test_FHS_compliance(tmp_path, package, fhscheck):
+@pytest.mark.parametrize('package', [NoFHSPackage])
+def test_FHS_compliance(package, fhscheck):
     """
     Check that the directories are not FHS compliant.
     """
     output, test = fhscheck
-    test.check(get_tested_package(package, tmp_path))
+    test.check(package)
     out = output.print_results(output.results)
 
     # Check invalid /usr subdirectory
