@@ -46,7 +46,7 @@ view)
     do_view_action "${filetype}"
     ;;
 open)
-    test -n "$DISPLAY" && ("${MC_XDG_OPEN}" "${MC_EXT_FILENAME}" >/dev/null 2>&1) || \
+    [ -n "$DISPLAY" ] && ("${MC_XDG_OPEN}" "${MC_EXT_FILENAME}" >/dev/null 2>&1 &) || \
         do_open_action "${filetype}"
     ;;
 *)
